Search lines which respects query on all their elements.
Source:R/funcs_FunctionFiltering.R
GetIndices_WholeLine.RdThis function looks for the lines where each element respect the query.
Examples
data(subR25pept)
level <- 'peptide'
pattern <- "Missing POV"
metacell.mask <- match.metacell(metadata = qMetacell(subR25pept[[1]]),
pattern = pattern, level = level)
ind <- GetIndices_WholeLine(metacell.mask)