Search lines which respects request on one or more conditions.
Source:R/funcs_FunctionFiltering.R
GetIndices_WholeMatrix.RdThis function looks for the lines that respect the request in either all conditions or at least one condition.
Examples
data(subR25pept)
level <- 'peptide'
pattern <- "Missing"
metacell.mask <- match.metacell(
metadata = qMetacell(subR25pept[[1]]), pattern = pattern, level = level)
percent <- FALSE
th <- 3
op <- ">="
ind <- GetIndices_WholeMatrix(metacell.mask, op, percent, th)