This plot compares the quantitative proteomics data between two assays. It can be used for example to compare the effect of the normalization process.
The comparison is made with the division operator.
Usage
plotCompareAssays(
obj,
i,
j,
info = NULL,
pal.name = "Set1",
subset.view = NULL,
n = 100,
type = "scatter",
FUN = NULL
)Examples
data(subR25prot)
plotCompareAssays(subR25prot, 1, 2, n = 5)