Build the list of connex composant of the adjacency matrix
Source:R/get_pep_prot_cc.R
get.pep.prot.cc.RdBuild the list of connex composant of the adjacency matrix
Examples
data(subR25pept)
X <- QFeatures::adjacencyMatrix(subR25pept[[1]])
ll <- get.pep.prot.cc(X)