Builds the design matrix for designs of level 1
Arguments
- sTab
The data.frame which correspond to the
pData()function of packageMSnbase.
Builds the design matrix for designs of level 1
The data.frame which correspond to the pData() function
of package MSnbase.