Imputation of peptides having no values in a biological condition.
Source:R/missingValuesImputation_PeptideLevel.R
wrapper.impute.mle.RdThis method is a wrapper to the function impute.mle() of the
package imp4p adapted to an object of class SummarizedExperiment.
It does not impute MEC missing values.
Examples
utils::data(subR25pept)
level <- 'peptide'
# Delete whole empty lines
metacell.mask <- DaparToolshed::match.metacell(
qMetacell(subR25pept[[1]]),
c("Missing POV", "Missing MEC"), level)
indices <- GetIndices_WholeMatrix(metacell.mask, op = ">=", th = 1)
grp <- design.qf(subR25pept)$Condition
subR25pept <- wrapper.impute.mle(subR25pept[[2]], grp)