Sets the metacell dataframe for datasets which are from Dia-NN software
Source:R/metacell.R
Metacell_DIA_NN.RdActually, this function uses the generic function to generate metacell info
R/metacell.R
Metacell_DIA_NN.RdActually, this function uses the generic function to generate metacell info