Sets the metacell dataframe for datasets which are from Proline software
Source:R/metacell.R
Metacell_proline.RdIn the quantitative columns, a missing value is identified by no value rather than a value equal to 0.
In these datasets, the metacell info is computed from the 'PSM count' columns.
Conversion rules Initial conversion rules for proline |————–|—————–|—–| | Quanti | PSM count | Tag | |————–|—————–|—–| | == 0 | N.A. | whatever | 2.0 | | > 0 | > 0 | 1.1 | | > 0 | == 0 | 1.2 | | > 0 | unknown col | 1.0 | |————–|—————–|—–|